@@ -21,5 +21,5 @@ class AddTemplatePartitionView(generic.ObjectEditView):
     form = PartitionTemplateForm
 
 
-class SyncTemplateToVMView():
+class SyncTemplateToVMView(generic.ObjectView):
     print("Hello")
